pub enum VmRuntimeError {
VmAlreadyExists(String),
VmNotFound(String),
InvalidTransition {
vm_id: String,
from: String,
to: &'static str,
},
SnapshotAlreadyExists {
vm_id: String,
snapshot_id: String,
},
StatePoisoned,
Unsupported(String),
}Expand description
Errors that can occur during microVM lifecycle or query operations.
Variants
VmAlreadyExists(String)
Attempted to create a VM with an identifier that is already in use.
VmNotFound(String)
Referenced a VM identifier that does not exist.
InvalidTransition
A lifecycle transition was requested that is not valid from the current state.
SnapshotAlreadyExists
Attempted to create a snapshot with an identifier that already exists on the VM.
StatePoisoned
Internal lock was poisoned by a panicking thread.
Unsupported(String)
Backend is not supported in the current build/config.